;
;  util.dat file format definition for PCC's util.dat browser
;
;  Assignments:
;     h = header (with placeholders, 15 chars max)
;     t = text (multiple lines allowed, with placeholders)
;     a = alias; use text from different record
;     l = loop size. Generate multiple messages, each consuming /l/
;         bytes
;     f = fixed size. Initial portion of this size is part of every
;         record
;     m = maximum bytes to load, truncate record if it is longer
;
;  Placeholders:
;     %<nn><flags><typ>
;  <nn> is the byte offset; can be omitted to take the default (=next)
;  <flags> can be
;     '?'     if item does not exist, use default (empty string or value
;             zero), do not treat as non-existant value.
;     '!'     for numbers: print it even if it is -1 (=unknown)
;  <typ> can be:
;     %%          percent sign
;     %|          two spaces (to avoid trimming of initial space)
;     %b          byte
;     %B          word, bitflag
;     %F          long, fixed-point number; displayed as 'X / 1000'
;     %g          word, native government shown as name
;     %h          word, hull number shown as name
;     %H          word, hull function shown as name
;     %l          long
;     %n          word, native race number shown as name
;     %p          word, planet number shown as name
;     %r          word, player number shown as race name
;     %R          word, right-justified to 5 places
;     %Snn        string of given length (must be two digits!)
;     %u          word, util.dat record name
;     %w          word
;     %W          word, padded to 4 digits
;     %x          hex word
;     %X          hex long
;     %(a,b,c)    word, enum, can be split over many lines if needed
;  By default, lines are omitted if a placeholder refers to a non-existant
;  value, where non-existant means not contained in the file, or a numeric
;  value of -1 (unless '!' was given) or 0 (for names)
;
;  This corresponds to the PHost 4.1a working version of 30/Jan/2007.
;
0,Mine Scan
        h = (-m%W)
        t = Minefield Id: %w
        t = Location:     (%w,%w)
        t = Owner:        %r
        t = Mine Units:   %l
        t = Type:         %(normal,web)
        t = Controlling Planet: %p
        t = Scan Type:    %(lay,sweep,scan)

1,Explosion
        h = (-x0000)
        t = Location:  (%w,%w)
        t = Ship Id:   %w
        t = Ship Name: %S20

2,Mine Hit
        h = (-e%W)
        t = Ship Id:   %w
        t = Location:  (%w,%w)
        t = Damage:    %d%%
        t = Ship Name: %S20

3,Dark Sense
        h = (-z%W)
        t = Planet Id:  %w
        t = Owner:      %r
        t = Neutronium: %l kt
        t = Tritanium:  %l kt
        t = Duranium:   %l kt
        t = Molybdenum: %l kt
        t = Money:      %l mc
        t = Starbase:   %(no,yes)

4,Super Spy
        h = (-p%W)
        t = Planet Id:  %w
        t = Mines:      %w
        t = Factories:  %w
        t = Defense:    %w
        t = Friendly Code: '%S03'
        t = Neutronium: %l kt
        t = Tritanium:  %l kt
        t = Duranium:   %l kt
        t = Molybdenum: %l kt
        t = Money:      %l mc
        t = Supplies:   %l kt

5,Exploration
        h = (-z%W)
        t = Planet Id:   %w
        t = Temperature: %w F
        t = Owner:       %r
        t = Colonists:   %l
        t = Starbase:    %(no,yes)

6,Sensor Sweep
        h = (-z%W)
        t = Planet Id:   %w
        t = Owner:       %r
        t = Activity:    %(minimal,light,moderate,substantial,heavy,very heavy)

7,Battle Result
        h = (-f%W)
        t = Left:
        t = %|Ship %0w, %6r
        t = %|Damage: %10w%%
        t = %|Torps: %14w
        t = %|Fighters: %18w
        t = %|%22(Survived,Got captured,Got destroyed,Out of ammo)
        t =
        t = Right:
        t = %|%4(Ship,Planet) %2w, %8r
        t = %|Damage: %12w%%
        t = %|Torps: %16w
        t = %|Fighters: %20w
        t = %|%24(Survived,Got captured,Got destroyed,Out of ammo)
        t =
        t = Location:    (%26w,%w)
        t = Random Seed: $%x

8,Meteor Strike
        h = (-p%W)
        t = Planet Id:  %w
        t = Neutronium: %l kt
        t = Tritanium:  %l kt
        t = Duranium:   %l kt
        t = Molybdenum: %l kt

9,Meteorite Shower
        h = (-p%W)
        a = 8

10,Ship Target
        h = (-s%W)
        t = Ship Id:   %w
        t = Owner:     %r
        t = Speed:     warp %w
        t = Location:  (%w,%w)
        t = Type:      %h
        t = Heading:   %w
        t = Name:      %S20

11,Starbase Target
        h = (-p%W)
        t = Planet %p
        t = owned by %r
        t = has a starbase.

12,Planet Target
        h = (-p%W)
        t = Planet Id:   %w
        t = Owner:       %r
        t = Temperature: %w F
        t = Native Race: %n
        t = Native Govm: %g
        t = Natives:     %l
        t = Neutronium:  %l kt
        t = Tritanium:   %l kt
        t = Duranium:    %l kt
        t = Molybdenum:  %l kt
        t = Colonists:   %l
        t = Supplies:    %l kt
        t = Money:       %l mc

13,Control Record
        h = (-h0000)
        t = Turn %18w for player %20w
        t =
        t = Host Time: %0S10 at %10S08
        t = Version:   PHost %22b.%23b%88?S01
        t = Game Name: %56S32
        t =
        t = Host file digests:
        t = %|HUL=%24X, ENG=%X,
        t = %|BEA=%X, TOR=%X,
        t = %|TRU=%X, PXY=%X,
        t = %|CFG=%X, NAM=%X.

14,Wormhole Scan
        h = (-u%10?W)
        t = Location:    (%w,%w)
        t = Mass:        %w kt
        t = Stability:   %(very stable,stable,quite stable,unstable,very unstable,totally unstable)
        t = Wormhole Id: %w
        t = Ufo Id:      %w
        t = %(Unidirectional,Bidirectional)

15,Wormhole Travel
        h = (-s%W)
        t = Ship Id:      %w
        t = Location:     (%w,%w)
        t = Damage taken: %w%%
        t = Total damage: %w%%
        t = Wormhole Id:  %w

16,Ship Recycled
        h = (-d%2W)
        t = Ship Id:  %w
        t = Base Id:  %w

17,Ion Storm
        h = (-i%W)
        t = Storm Id: %w
        t = Location: (%w,%w)
        t = Voltage:  %w MeV
        t = Heading:  %w
        t = Speed:    warp %w
        t = Radius:   %w ly
        t = Class:    %w
        t = Status:   %(weakening,growing)

18,Ship Colonized
        h = (-p%2W)
        t = Ship Id:   %w
        t = Planet Id: %w

19,Ship Surrendered
        h = (-d%4W)
        t = Ship Id:        %w
        t = Original Owner: %r
        t = Base Id:        %w
        t = Base Owner:     %w

20,Ship Constructed
        h = (-d%2W)
        t = Ship Id:     %w
        t = Base Id:     %w
        t = %(Normal build,Cloned)

21,Ship Trade
        h = (-s%W)
        t = Ship Id:   %w
        t = Old owner: %r
        t = New owner: %r

22,Alliance Status
        h = (-h0000)
        t = Sorry, this record cannot be
        t = decoded here. See the alliance
        t = screen or the subspace message
        t = for your alliance status.

23,Bioscan Report
        h = (-z%W)
        t = Planet Id:         %w
        t = Native Race:       %n
        t = Native Population: %l
        t = Temperature:       %w F

24,Glory Device Exploded
        h = (-s0000)
        t = Ship Id:   %w
        t = Location:  (%w,%w)

25,Damage from Glory Device
        h = (-e%W)
        t = Ship Id:    %w
        t = Location:   (%w,%w)
        t = Damage Now: %w%%
        t = Ship Owner: %r
        t = Ship Type:  %h
        t = Ship Name:  %S20

26,Boarding Party
        h = (-s%W)
        t = Ship Id:       %w
        t = Old Owner:     %r
        t = New Owner:     %r
        t = Boarding Ship: %w

27,Configuration File
        h = (-h0000)
        m = 0
        t = This record contains the configuration
        t = file, PCONFIG.SRC. PCC should have
        t = received that file during unpack.

28,Ground Attack
        h = (-p%W)
        t = Planet Id:    %w
        t = Owner:        %r
        t = Attacker:     %r
        t = %(Owner won,Attacker won,Mutual annihilation)

29,Minefields Exploding
        h = (-m%4W)
        t = Minefield 1: %4w at (%0w,%w)
        t = Minefield 2: %10w at (%6w,%w)
        t = Units Lost:  %12l

30,End of PHost Info
        h = (-h0000)
        t = This record marks the end of
        t = the file as PHost wrote it.
        t = Everything that follows was
        t = added by add-on programs.

31,Minefield Scooping
        h = (-s%W)
        t = Ship Id:         %w
        t = Minefield Id:    %w
        t = Torps Converted: %w
        t = Units Scooped:   %l
        t = Units Before:    %l

32,Pillage
        h = (-p%W)
        t = Planet Id:      %w
        t = Colonist Clans: %l
        t = Native Clans:   %l
        t = Ship Owner:     %r

33,Object
        m = 76
        h = (-u%W)
        t = Object Id:   %w
        t = Location:    (%w,%w)
        t = Color:       %(black,blue,green,cyan,red,magenta,brown,gray,dark-gray,light-blue,light-green,light-cyan,light-red,light-magenta,yellow,white)
        t = Radius:      %w ly
        t = Speed:       warp %w
        t = Heading:     %w
        t = Name:        %S20
        t = Description: %S20
        t = %|           %S20
        t = Type Code:   %w

34,File Transfer
        m = 13
        h = (-h0000)
      ; This does not work, because it's only one byte:
      ; t = This record contains the %12(binary,text) file
        t = This record contains the file
        t = %0S12. PCC should have extracted
        t = this file during unpack.

35,Cloak Failure
        h = (-s%W)
        t = Ship Id:   %w
        t = Reason:    %(random chance,no fuel,excess damage,ionic pulse,wormhole,anti-cloak ship,ion storm)

36,Anti Cloak
        h = (-s%W)
        t = Ship Id:   %w
        t = Location:  (%w,%w)
        t = Owner:     %r
        t = %(Before Movement,After Movement)

37,Remote Control
        h = (-h0000)
        t = This record contains information about
        t = remote control. PCC should have decoded
        t = that already, see the ship screens and/
        t = or the sub-space messages.

38,Activity Level Report
        h = (-h0000)
        t = Old Score:       %l
        t = Decayed Points: -%l
        t = New Points:     +%l
        t = New Score:       %l

39,Build Queue Report
        l = 10
        h = (-d%W)
        t = Base Id:    %w
        t = Hull Type:  %h
        t = Position:   %w
        t = Priority:   %l

40,Web Drain Complete
        h = (-w%W)
        t = Ship Id:   %w
        t = Owner:     %r
        t = Ship Name: %S20

41,Rebel Ground Attack
        h = (-p%W)
        t = Planet Id:   %w
        t = Natives:     %(no,yes)
        t = Attacker:    %r

42,Object Destroyed
        h = (-u%W)
        t = Object Id: %w
        t = Type Code: %w

43,Minefield Status
        h = (-h0000)
        t = %|      Minefields
        t = Player Allowed  Laid
        t = ------ ------- -------
        T = %| 1    %0R   %22R
        T = %| 2    %2R   %24R
        T = %| 3    %4R   %26R
        T = %| 4    %6R   %28R
        T = %| 5    %8R   %30R
        T = %| 6    %10R   %32R
        T = %| 7    %12R   %34R
        T = %| 8    %14R   %36R
        T = %| 9    %16R   %38R
        T = %|10    %18R   %40R
        T = %|11    %20R   %42R

44,Failure Notice
        ;; we give it a '-s' header although '-p' might sometimes 
        ;; be more appropriate. The decoder cannot handle that yet, though.
        ;; It would be nice to say something about missions, too.
        h = (-s%2W)
        t = Action:    %u
        t = Ship Id:   %w
        t = Planet Id: %w
        t = Cause:     %(random chance,no fuel,damage,ionic pulse,wormhole,anti-cloak ship,ion storm,7,8,9,
        t = no minerals,no tech,no receiver,disabled in configuration,not allowed by rule,
        t = not allowed by partner,all slots full,limit exceeded,required ability missing,
        t = target does not exist,per-unit limit exceeded)

45,Planet Trade
        h = (-p%W)
        t = Planet Id: %w
        t = Old Owner: %r
        t = New Owner: %r

46,Mine Scan (High-Id)
        h = (-m%W)
        a = 0

47,Nonexistant Planets
        ;; This will generate one message per non-existant planet.
        ;; Not quite optimal; users can plonk it if they don't like it.
        h = (-p%W)
        l = 2
        t = Planet %p does not exist.

48,PAL Summary
        h = (-h0000)
        t = Player 1: %l
        t = Player 2: %l
        t = Player 3: %l
        t = Player 4: %l
        t = Player 5: %l
        t = Player 6: %l
        t = Player 7: %l
        t = Player 8: %l
        t = Player 9: %l
        t = Player 10: %l
        t = Player 11: %l

49,Ship Score
        f = 54
        l = 36
        h = (-h0000)
        t = This record contains ship score %50w,
        t = %0S50.
        t =
        t = Maximum score: %52w.
        t =
        t = Ship   Score
        t = -----  -----
        t = %54R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R

50,Planet Score
        f = 54
        l = 36
        h = (-h0000)
        t = This record contains planet score %50w,
        t = %0S50.
        t =
        t = Maximum score: %52w.
        t =
        t = Planet Score
        t = -----  -----
        t = %54R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R
        t = %R  %R

51,Player Score
        h = (-h0000)
        t = This record contains player score %50w,
        t = %0S50.
        t =
        t = Winning condition: %54l points
        t = for %52w turns.
        t =
        t = Player 1: %58l
        t = Player 2: %l
        t = Player 3: %l
        t = Player 4: %l
        t = Player 5: %l
        t = Player 6: %l
        t = Player 7: %l
        t = Player 8: %l
        t = Player 9: %l
        t = Player 10: %l
        t = Player 11: %l

52,Ship Abilities
        l = 2
        f = 2
        h = (-s%W)
        t = Ship %w has a special function:
        t = %H

53,Minefields Exploding
        h = (-m%W)
        t = Minefield %4w at (%0w,%w)
        t = Units Lost: %6l

54,Enemy Status
        ;; re-use the alliance message
        h = (-h0000)
        a = 22

55,Production Report
        h = (-s%W)
        t = Ship Id:   %w
        t = Produced: %6w %2(kt Fuel,kt Tritanium,kt Duranium,kt Molybdenum,Colonist clans,kt Supplies,mc,Torpedoes/Fighters,Experience)
        t = %(No resources used,Ship cargo used,Planetary resources used,Ship and planet resources used)

56,Repair Report
        h = (-s%W)
        t = Ship Id:     %w
        t = Reason:      %(Supply Repair,Starbase,Self Repair mission,Super Refit mission,Repair Ship mission)
        t = Repaired by: %w
        t = Damage Repaired: %w%%
        t = Crew Added:  %w

57,Ship Abilities
        h = (-h0000)
        t = Special function %w is a
        t = %H device
        t = that works on experience
        t = levels %B.

58,Explosion
        h = (-x0000)
        t = A ship exploded in a minefield
        t = at (%w,%w)

; This record is there to have something sensible for failure messages
; (type 44) with Action=10000.
10000,Starship Mission
        m = 0
        h = (-h0000)
        t = This is a pseudo record.
        t = You should never see it.

; Local Variables:
; mode: ccspec
; End:
